==> gorilla-notebook-0.4.0.jar: gorilla-repl-client/js/cljs/cljs-runtime/pinkgorilla.explore.subs.js <==
goog.provide('pinkgorilla.explore.subs');
goog.require('cljs.core');
goog.require('re_frame.core');
goog.require('clojure.string');
goog.require('clojure.set');
goog.require('pinkgorilla.explore.utils');
pinkgorilla.explore.subs.path_reaction = (function pinkgorilla$explore$subs$path_reaction(db,path){
return reagent.ratom.make_reaction((function (){
return cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(cljs.core.deref(db),path);
}));
});
re_frame.core.reg_sub_raw(new cljs.core.Keyword(null,"key","key",-1516042587),(function (db,p__18210){
var vec__18211 = p__18210;
var seq__18212 = cljs.core.seq(vec__18211);
var first__18213 = cljs.core.first(seq__18212);
var seq__18212__$1 = cljs.core.next(seq__18212);
var _ = first__18213;
var path = seq__18212__$1;
return reagent.ratom.make_reaction((function (){
return cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(cljs.core.deref(db),path);
}));
}));
re_frame.core.reg_sub_raw(new cljs.core.Keyword(null,"form-data","form-data",1829298254),(function (db,p__18214){
var vec__18215 = p__18214;
var seq__18216 = cljs.core.seq(vec__18215);
var first__18217 = cljs.core.first(seq__18216);
var seq__18216__$1 = cljs.core.next(seq__18216);
var _ = first__18217;
var path = seq__18216__$1;
return reagent.ratom.make_reaction((function (){
return cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(cljs.core.deref(db),cljs.core.concat.cljs$core$IFn$_invoke$arity$variadic(new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"forms","forms",2045992350)], null),path,cljs.core.prim_seq.cljs$core$IFn$_invoke$arity$2([new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"data","data",-232669377)], null)], 0)));
}));
}));
pinkgorilla.explore.subs.filter_items = (function pinkgorilla$explore$subs$filter_items(query,items){
if(cljs.core.empty_QMARK_(query)){
return items;
} else {
var query__$1 = clojure.string.lower_case(query);
return cljs.core.filter.cljs$core$IFn$_invoke$arity$2((function (item){
return cljs.core.not_EQ_.cljs$core$IFn$_invoke$arity$2((-1),clojure.string.lower_case(clojure.string.join.cljs$core$IFn$_invoke$arity$2(" ",cljs.core.filter.cljs$core$IFn$_invoke$arity$2(cljs.core.string_QMARK_,cljs.core.vals(item)))).indexOf(query__$1));
}),items);
}
});
pinkgorilla.explore.subs.filter_query = (function pinkgorilla$explore$subs$filter_query(db,query_path,items){
var query = pinkgorilla.explore.subs.path_reaction(db,query_path);
return reagent.ratom.make_reaction((function (){
return pinkgorilla.explore.subs.filter_items(cljs.core.deref(query),cljs.core.deref(items));
}));
});
pinkgorilla.explore.subs.filter_tags = (function pinkgorilla$explore$subs$filter_tags(db,tag_path,items){
var tags = pinkgorilla.explore.subs.path_reaction(db,tag_path);
return reagent.ratom.make_reaction((function (){
var tag_set = cljs.core.set(cljs.core.deref(tags));
var items__$1 = cljs.core.deref(items);
var _ = cljs.core.println.cljs$core$IFn$_invoke$arity$variadic(cljs.core.prim_seq.cljs$core$IFn$_invoke$arity$2(["filtering tags: ",tag_set," empty:",cljs.core.empty_QMARK_(tag_set)," count:",cljs.core.count(tag_set)," tags not set: ",cljs.core.deref(tags)], 0));
if(cljs.core.empty_QMARK_(tag_set)){
return items__$1;
} else {
return cljs.core.filter.cljs$core$IFn$_invoke$arity$2((function (p1__18218_SHARP_){
return cljs.core.every_QMARK_(cljs.core.set(pinkgorilla.explore.utils.split_tags(cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(p1__18218_SHARP_,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"meta","meta",1499536964),new cljs.core.Keyword(null,"tags","tags",1771418977)], null)))),tag_set);
}),items__$1);
}
}));
});
pinkgorilla.explore.subs.filter_toggle = (function pinkgorilla$explore$subs$filter_toggle(db,toggle_path,items){
var toggle = pinkgorilla.explore.subs.path_reaction(db,toggle_path);
return reagent.ratom.make_reaction((function (){
if(cljs.core.truth_(cljs.core.deref(toggle))){
return cljs.core.filter.cljs$core$IFn$_invoke$arity$2(cljs.core.last(toggle_path),cljs.core.deref(items));
} else {
return cljs.core.deref(items);
}
}));
});
re_frame.core.reg_sub_raw(new cljs.core.Keyword(null,"filtered-projects","filtered-projects",239301462),(function (db,_){
var items = pinkgorilla.explore.subs.path_reaction(db,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"data","data",-232669377),new cljs.core.Keyword(null,"projects","projects",-364845983)], null));
var ___$1 = cljs.core.println.cljs$core$IFn$_invoke$arity$variadic(cljs.core.prim_seq.cljs$core$IFn$_invoke$arity$2(["filtered notebook item count: ",cljs.core.count(cljs.core.deref(items))], 0));
return pinkgorilla.explore.subs.filter_tags(db,new cljs.core.PersistentVector(null, 5, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"forms","forms",2045992350),new cljs.core.Keyword(null,"projects","projects",-364845983),new cljs.core.Keyword(null,"search","search",1564939822),new cljs.core.Keyword(null,"data","data",-232669377),new cljs.core.Keyword(null,"tags","tags",1771418977)], null),pinkgorilla.explore.subs.filter_query(db,new cljs.core.PersistentVector(null, 5, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"forms","forms",2045992350),new cljs.core.Keyword(null,"projects","projects",-364845983),new cljs.core.Keyword(null,"search","search",1564939822),new cljs.core.Keyword(null,"data","data",-232669377),new cljs.core.Keyword(null,"query","query",-1288509510)], null),items));
}));
re_frame.core.reg_sub_raw(new cljs.core.Keyword(null,"project-tags","project-tags",-1698165588),(function (db,_){
var listings = (function (){var G__18219 = new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"filtered-projects","filtered-projects",239301462)], null);
return (re_frame.core.subscribe.cljs$core$IFn$_invoke$arity$1 ? re_frame.core.subscribe.cljs$core$IFn$_invoke$arity$1(G__18219) : re_frame.core.subscribe.call(null,G__18219));
})();
return reagent.ratom.make_reaction((function (){
return cljs.core.sort.cljs$core$IFn$_invoke$arity$1(cljs.core.distinct.cljs$core$IFn$_invoke$arity$1(cljs.core.map.cljs$core$IFn$_invoke$arity$2(cljs.core.comp.cljs$core$IFn$_invoke$arity$2(clojure.string.lower_case,clojure.string.trim),cljs.core.mapcat.cljs$core$IFn$_invoke$arity$variadic((function (l){
return clojure.string.split.cljs$core$IFn$_invoke$arity$2(cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(l,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"meta","meta",1499536964),new cljs.core.Keyword(null,"tags","tags",1771418977)], null)),",");
}),cljs.core.prim_seq.cljs$core$IFn$_invoke$arity$2([cljs.core.deref(listings)], 0)))));
}));
}));

//# sourceMappingURL=pinkgorilla.explore.subs.js.map

==> gorilla-notebook-0.4.4.jar: gorilla-repl-client/js/cljs/cljs-runtime/pinkgorilla.explore.subs.js <==
goog.provide('pinkgorilla.explore.subs');
goog.require('cljs.core');
goog.require('re_frame.core');
goog.require('clojure.string');
goog.require('pinkgorilla.explore.utils');
pinkgorilla.explore.subs.path_reaction = (function pinkgorilla$explore$subs$path_reaction(db,path){
return reagent.ratom.make_reaction((function (){
return cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(cljs.core.deref(db),path);
}));
});
re_frame.core.reg_sub_raw(new cljs.core.Keyword(null,"key","key",-1516042587),(function (db,p__53340){
var vec__53341 = p__53340;
var seq__53342 = cljs.core.seq(vec__53341);
var first__53343 = cljs.core.first(seq__53342);
var seq__53342__$1 = cljs.core.next(seq__53342);
var _ = first__53343;
var path = seq__53342__$1;
return reagent.ratom.make_reaction((function (){
return cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(cljs.core.deref(db),path);
}));
}));
re_frame.core.reg_sub_raw(new cljs.core.Keyword(null,"form-data","form-data",1829298254),(function (db,p__53344){
var vec__53345 = p__53344;
var seq__53346 = cljs.core.seq(vec__53345);
var first__53347 = cljs.core.first(seq__53346);
var seq__53346__$1 = cljs.core.next(seq__53346);
var _ = first__53347;
var path = seq__53346__$1;
return reagent.ratom.make_reaction((function (){
return cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(cljs.core.deref(db),cljs.core.concat.cljs$core$IFn$_invoke$arity$variadic(new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"forms","forms",2045992350)], null),path,cljs.core.prim_seq.cljs$core$IFn$_invoke$arity$2([new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"data","data",-232669377)], null)], 0)));
}));
}));
pinkgorilla.explore.subs.filter_items = (function pinkgorilla$explore$subs$filter_items(query,items){
if(cljs.core.empty_QMARK_(query)){
return items;
} else {
var query__$1 = clojure.string.lower_case(query);
return cljs.core.filter.cljs$core$IFn$_invoke$arity$2((function (item){
return cljs.core.not_EQ_.cljs$core$IFn$_invoke$arity$2((-1),clojure.string.lower_case(clojure.string.join.cljs$core$IFn$_invoke$arity$2(" ",cljs.core.filter.cljs$core$IFn$_invoke$arity$2(cljs.core.string_QMARK_,cljs.core.vals(item)))).indexOf(query__$1));
}),items);
}
});
pinkgorilla.explore.subs.filter_query = (function pinkgorilla$explore$subs$filter_query(db,query_path,items){
var query = pinkgorilla.explore.subs.path_reaction(db,query_path);
return reagent.ratom.make_reaction((function (){
return pinkgorilla.explore.subs.filter_items(cljs.core.deref(query),cljs.core.deref(items));
}));
});
pinkgorilla.explore.subs.filter_tags = (function pinkgorilla$explore$subs$filter_tags(db,tag_path,items){
var tags = pinkgorilla.explore.subs.path_reaction(db,tag_path);
return reagent.ratom.make_reaction((function (){
var tag_set = cljs.core.set(cljs.core.deref(tags));
var items__$1 = cljs.core.deref(items);
var _ = cljs.core.println.cljs$core$IFn$_invoke$arity$variadic(cljs.core.prim_seq.cljs$core$IFn$_invoke$arity$2(["filtering tags: ",tag_set," empty:",cljs.core.empty_QMARK_(tag_set)," count:",cljs.core.count(tag_set)," tags not set: ",cljs.core.deref(tags)], 0));
if(cljs.core.empty_QMARK_(tag_set)){
return items__$1;
} else {
return cljs.core.filter.cljs$core$IFn$_invoke$arity$2((function (p1__53348_SHARP_){
return cljs.core.every_QMARK_(cljs.core.set(pinkgorilla.explore.utils.split_tags(cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(p1__53348_SHARP_,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"meta","meta",1499536964),new cljs.core.Keyword(null,"tags","tags",1771418977)], null)))),tag_set);
}),items__$1);
}
}));
});
pinkgorilla.explore.subs.filter_toggle = (function pinkgorilla$explore$subs$filter_toggle(db,toggle_path,items){
var toggle = pinkgorilla.explore.subs.path_reaction(db,toggle_path);
return reagent.ratom.make_reaction((function (){
if(cljs.core.truth_(cljs.core.deref(toggle))){
return cljs.core.filter.cljs$core$IFn$_invoke$arity$2(cljs.core.last(toggle_path),cljs.core.deref(items));
} else {
return cljs.core.deref(items);
}
}));
});
re_frame.core.reg_sub_raw(new cljs.core.Keyword(null,"filtered-projects","filtered-projects",239301462),(function (db,_){
var items = pinkgorilla.explore.subs.path_reaction(db,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"data","data",-232669377),new cljs.core.Keyword(null,"projects","projects",-364845983)], null));
var ___$1 = cljs.core.println.cljs$core$IFn$_invoke$arity$variadic(cljs.core.prim_seq.cljs$core$IFn$_invoke$arity$2(["filtered notebook item count: ",cljs.core.count(cljs.core.deref(items))], 0));
return pinkgorilla.explore.subs.filter_tags(db,new cljs.core.PersistentVector(null, 5, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"forms","forms",2045992350),new cljs.core.Keyword(null,"projects","projects",-364845983),new cljs.core.Keyword(null,"search","search",1564939822),new cljs.core.Keyword(null,"data","data",-232669377),new cljs.core.Keyword(null,"tags","tags",1771418977)], null),pinkgorilla.explore.subs.filter_query(db,new cljs.core.PersistentVector(null, 5, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"forms","forms",2045992350),new cljs.core.Keyword(null,"projects","projects",-364845983),new cljs.core.Keyword(null,"search","search",1564939822),new cljs.core.Keyword(null,"data","data",-232669377),new cljs.core.Keyword(null,"query","query",-1288509510)], null),items));
}));
re_frame.core.reg_sub_raw(new cljs.core.Keyword(null,"project-tags","project-tags",-1698165588),(function (_,___$1){
var listings = (function (){var G__53349 = new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"filtered-projects","filtered-projects",239301462)], null);
return (re_frame.core.subscribe.cljs$core$IFn$_invoke$arity$1 ? re_frame.core.subscribe.cljs$core$IFn$_invoke$arity$1(G__53349) : re_frame.core.subscribe.call(null,G__53349));
})();
return reagent.ratom.make_reaction((function (){
return cljs.core.sort.cljs$core$IFn$_invoke$arity$1(cljs.core.distinct.cljs$core$IFn$_invoke$arity$1(cljs.core.map.cljs$core$IFn$_invoke$arity$2(cljs.core.comp.cljs$core$IFn$_invoke$arity$2(clojure.string.lower_case,clojure.string.trim),cljs.core.mapcat.cljs$core$IFn$_invoke$arity$variadic((function (l){
return clojure.string.split.cljs$core$IFn$_invoke$arity$2(cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(l,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"meta","meta",1499536964),new cljs.core.Keyword(null,"tags","tags",1771418977)], null)),",");
}),cljs.core.prim_seq.cljs$core$IFn$_invoke$arity$2([cljs.core.deref(listings)], 0)))));
}));
}));

//# sourceMappingURL=pinkgorilla.explore.subs.js.map
